package de.cliffbreak.varo;

import java.io.File;
import java.io.IOException;

import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.inventory.MainHand;
import org.bukkit.scheduler.BukkitRunnable;

public class PlayerCache {

    private Varo plugin;
    private File playerCacheFile = new File("plugins/CliffbreakVaro", "playercache.yml");
    private FileConfiguration playerCache = YamlConfiguration.loadConfiguration(this.playerCacheFile);
    private boolean wasSaved = false;

    public PlayerCache(Varo plugin) {
        this.plugin = plugin;
    }

    public void setPlayerCache(final String uuid, PlayerCacheType type, Object value) {
        this.playerCache.set("Players." + uuid + "." + type.toString(), value);
        savePlayerCache();
    }

    public int getSkinParts(final String uuid) {
        return (int) this.playerCache.get("Players." + uuid + "." + PlayerCacheType.SKINPARTS.toString());
    }

    public MainHand getMainHand(final String uuid) {
        return MainHand.valueOf(
                this.playerCache.get("Players." + uuid + "." + PlayerCacheType.MAINHAND.toString()).toString());
    }

    public byte getMainHandAsByte(final String uuid) {
        if (getMainHand(uuid) == MainHand.RIGHT)
            return (byte) 1;
        else
            return (byte) 0;
    }

    public void shutdown() {
        try {
            plugin.getLogger().info("Saving PlayerCache...");
            this.playerCache.save(this.playerCacheFile);
        } catch (final IOException e) {
            e.printStackTrace();
        }
    }

    private void savePlayerCache() {
        if (!this.wasSaved)
            try {
                plugin.getLogger().info("Saving PlayerCache...");
                this.playerCache.save(this.playerCacheFile);
                this.wasSaved = true;
                new BukkitRunnable() {

                    @Override
                    public void run() {
                        wasSaved = false;
                    }
                }.runTaskLater(plugin, 20); // Only save once every second to prevent disklock
            } catch (final IOException e) {
                e.printStackTrace();
            }
    }

    public enum PlayerCacheType {
        SKINPARTS, MAINHAND,
    }
}